# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import wavefront_api_client
from wavefront_api_client.api.search_api import SearchApi  # noqa: E501
from wavefront_api_client.rest import ApiException


class TestSearchApi(unittest.TestCase):
    """SearchApi unit test stubs"""

    def setUp(self):
        self.api = wavefront_api_client.api.search_api.SearchApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_search_account_entities(self):
        """Test case for search_account_entities

        Search over a customer's accounts  # noqa: E501
        """
        pass

    def test_search_account_for_facet(self):
        """Test case for search_account_for_facet

        Lists the values of a specific facet over the customer's accounts  # noqa: E501
        """
        pass

    def test_search_account_for_facets(self):
        """Test case for search_account_for_facets

        Lists the values of one or more facets over the customer's accounts  # noqa: E501
        """
        pass

    def test_search_alert_deleted_entities(self):
        """Test case for search_alert_deleted_entities

        Search over a customer's deleted alerts  # noqa: E501
        """
        pass

    def test_search_alert_deleted_for_facet(self):
        """Test case for search_alert_deleted_for_facet

        Lists the values of a specific facet over the customer's deleted alerts  # noqa: E501
        """
        pass

    def test_search_alert_deleted_for_facets(self):
        """Test case for search_alert_deleted_for_facets

        Lists the values of one or more facets over the customer's deleted alerts  # noqa: E501
        """
        pass

    def test_search_alert_entities(self):
        """Test case for search_alert_entities

        Search over a customer's non-deleted alerts  # noqa: E501
        """
        pass

    def test_search_alert_for_facet(self):
        """Test case for search_alert_for_facet

        Lists the values of a specific facet over the customer's non-deleted alerts  # noqa: E501
        """
        pass

    def test_search_alert_for_facets(self):
        """Test case for search_alert_for_facets

        Lists the values of one or more facets over the customer's non-deleted alerts  # noqa: E501
        """
        pass

    def test_search_cloud_integration_deleted_entities(self):
        """Test case for search_cloud_integration_deleted_entities

        Search over a customer's deleted cloud integrations  # noqa: E501
        """
        pass

    def test_search_cloud_integration_deleted_for_facet(self):
        """Test case for search_cloud_integration_deleted_for_facet

        Lists the values of a specific facet over the customer's deleted cloud integrations  # noqa: E501
        """
        pass

    def test_search_cloud_integration_deleted_for_facets(self):
        """Test case for search_cloud_integration_deleted_for_facets

        Lists the values of one or more facets over the customer's deleted cloud integrations  # noqa: E501
        """
        pass

    def test_search_cloud_integration_entities(self):
        """Test case for search_cloud_integration_entities

        Search over a customer's non-deleted cloud integrations  # noqa: E501
        """
        pass

    def test_search_cloud_integration_for_facet(self):
        """Test case for search_cloud_integration_for_facet

        Lists the values of a specific facet over the customer's non-deleted cloud integrations  # noqa: E501
        """
        pass

    def test_search_cloud_integration_for_facets(self):
        """Test case for search_cloud_integration_for_facets

        Lists the values of one or more facets over the customer's non-deleted cloud integrations  # noqa: E501
        """
        pass

    def test_search_dashboard_deleted_entities(self):
        """Test case for search_dashboard_deleted_entities

        Search over a customer's deleted dashboards  # noqa: E501
        """
        pass

    def test_search_dashboard_deleted_for_facet(self):
        """Test case for search_dashboard_deleted_for_facet

        Lists the values of a specific facet over the customer's deleted dashboards  # noqa: E501
        """
        pass

    def test_search_dashboard_deleted_for_facets(self):
        """Test case for search_dashboard_deleted_for_facets

        Lists the values of one or more facets over the customer's deleted dashboards  # noqa: E501
        """
        pass

    def test_search_dashboard_entities(self):
        """Test case for search_dashboard_entities

        Search over a customer's non-deleted dashboards  # noqa: E501
        """
        pass

    def test_search_dashboard_for_facet(self):
        """Test case for search_dashboard_for_facet

        Lists the values of a specific facet over the customer's non-deleted dashboards  # noqa: E501
        """
        pass

    def test_search_dashboard_for_facets(self):
        """Test case for search_dashboard_for_facets

        Lists the values of one or more facets over the customer's non-deleted dashboards  # noqa: E501
        """
        pass

    def test_search_external_link_entities(self):
        """Test case for search_external_link_entities

        Search over a customer's external links  # noqa: E501
        """
        pass

    def test_search_external_links_for_facet(self):
        """Test case for search_external_links_for_facet

        Lists the values of a specific facet over the customer's external links  # noqa: E501
        """
        pass

    def test_search_external_links_for_facets(self):
        """Test case for search_external_links_for_facets

        Lists the values of one or more facets over the customer's external links  # noqa: E501
        """
        pass

    def test_search_ingestion_policy_entities(self):
        """Test case for search_ingestion_policy_entities

        Search over a customer's ingestion policies  # noqa: E501
        """
        pass

    def test_search_ingestion_policy_for_facet(self):
        """Test case for search_ingestion_policy_for_facet

        Lists the values of a specific facet over the customer's ingestion policies  # noqa: E501
        """
        pass

    def test_search_ingestion_policy_for_facets(self):
        """Test case for search_ingestion_policy_for_facets

        Lists the values of one or more facets over the customer's ingestion policies  # noqa: E501
        """
        pass

    def test_search_maintenance_window_entities(self):
        """Test case for search_maintenance_window_entities

        Search over a customer's maintenance windows  # noqa: E501
        """
        pass

    def test_search_maintenance_window_for_facet(self):
        """Test case for search_maintenance_window_for_facet

        Lists the values of a specific facet over the customer's maintenance windows  # noqa: E501
        """
        pass

    def test_search_maintenance_window_for_facets(self):
        """Test case for search_maintenance_window_for_facets

        Lists the values of one or more facets over the customer's maintenance windows  # noqa: E501
        """
        pass

    def test_search_monitored_application_entities(self):
        """Test case for search_monitored_application_entities

        Search over all the customer's non-deleted monitored applications  # noqa: E501
        """
        pass

    def test_search_monitored_application_for_facet(self):
        """Test case for search_monitored_application_for_facet

        Lists the values of a specific facet over the customer's non-deleted monitored application  # noqa: E501
        """
        pass

    def test_search_monitored_application_for_facets(self):
        """Test case for search_monitored_application_for_facets

        Lists the values of one or more facets over the customer's non-deleted monitored clusters  # noqa: E501
        """
        pass

    def test_search_monitored_service_entities(self):
        """Test case for search_monitored_service_entities

        Search over all the customer's non-deleted monitored services  # noqa: E501
        """
        pass

    def test_search_monitored_service_for_facet(self):
        """Test case for search_monitored_service_for_facet

        Lists the values of a specific facet over the customer's non-deleted monitored application  # noqa: E501
        """
        pass

    def test_search_monitored_service_for_facets(self):
        """Test case for search_monitored_service_for_facets

        Lists the values of one or more facets over the customer's non-deleted monitored clusters  # noqa: E501
        """
        pass

    def test_search_notficant_for_facets(self):
        """Test case for search_notficant_for_facets

        Lists the values of one or more facets over the customer's notificants  # noqa: E501
        """
        pass

    def test_search_notificant_entities(self):
        """Test case for search_notificant_entities

        Search over a customer's notificants  # noqa: E501
        """
        pass

    def test_search_notificant_for_facet(self):
        """Test case for search_notificant_for_facet

        Lists the values of a specific facet over the customer's notificants  # noqa: E501
        """
        pass

    def test_search_proxy_deleted_entities(self):
        """Test case for search_proxy_deleted_entities

        Search over a customer's deleted proxies  # noqa: E501
        """
        pass

    def test_search_proxy_deleted_for_facet(self):
        """Test case for search_proxy_deleted_for_facet

        Lists the values of a specific facet over the customer's deleted proxies  # noqa: E501
        """
        pass

    def test_search_proxy_deleted_for_facets(self):
        """Test case for search_proxy_deleted_for_facets

        Lists the values of one or more facets over the customer's deleted proxies  # noqa: E501
        """
        pass

    def test_search_proxy_entities(self):
        """Test case for search_proxy_entities

        Search over a customer's non-deleted proxies  # noqa: E501
        """
        pass

    def test_search_proxy_for_facet(self):
        """Test case for search_proxy_for_facet

        Lists the values of a specific facet over the customer's non-deleted proxies  # noqa: E501
        """
        pass

    def test_search_proxy_for_facets(self):
        """Test case for search_proxy_for_facets

        Lists the values of one or more facets over the customer's non-deleted proxies  # noqa: E501
        """
        pass

    def test_search_registered_query_deleted_entities(self):
        """Test case for search_registered_query_deleted_entities

        Search over a customer's deleted derived metric definitions  # noqa: E501
        """
        pass

    def test_search_registered_query_deleted_for_facet(self):
        """Test case for search_registered_query_deleted_for_facet

        Lists the values of a specific facet over the customer's deleted derived metric definitions  # noqa: E501
        """
        pass

    def test_search_registered_query_deleted_for_facets(self):
        """Test case for search_registered_query_deleted_for_facets

        Lists the values of one or more facets over the customer's deleted derived metric definitions  # noqa: E501
        """
        pass

    def test_search_registered_query_entities(self):
        """Test case for search_registered_query_entities

        Search over a customer's non-deleted derived metric definitions  # noqa: E501
        """
        pass

    def test_search_registered_query_for_facet(self):
        """Test case for search_registered_query_for_facet

        Lists the values of a specific facet over the customer's non-deleted derived metric definitions  # noqa: E501
        """
        pass

    def test_search_registered_query_for_facets(self):
        """Test case for search_registered_query_for_facets

        Lists the values of one or more facets over the customer's non-deleted derived metric definition  # noqa: E501
        """
        pass

    def test_search_related_report_event_anomaly_entities(self):
        """Test case for search_related_report_event_anomaly_entities

        List the related events and anomalies over a firing event  # noqa: E501
        """
        pass

    def test_search_related_report_event_entities(self):
        """Test case for search_related_report_event_entities

        List the related events over a firing event  # noqa: E501
        """
        pass

    def test_search_report_event_entities(self):
        """Test case for search_report_event_entities

        Search over a customer's events  # noqa: E501
        """
        pass

    def test_search_report_event_for_facet(self):
        """Test case for search_report_event_for_facet

        Lists the values of a specific facet over the customer's events  # noqa: E501
        """
        pass

    def test_search_report_event_for_facets(self):
        """Test case for search_report_event_for_facets

        Lists the values of one or more facets over the customer's events  # noqa: E501
        """
        pass

    def test_search_role_entities(self):
        """Test case for search_role_entities

        Search over a customer's roles  # noqa: E501
        """
        pass

    def test_search_role_for_facet(self):
        """Test case for search_role_for_facet

        Lists the values of a specific facet over the customer's roles  # noqa: E501
        """
        pass

    def test_search_role_for_facets(self):
        """Test case for search_role_for_facets

        Lists the values of one or more facets over the customer's roles  # noqa: E501
        """
        pass

    def test_search_service_account_entities(self):
        """Test case for search_service_account_entities

        Search over a customer's service accounts  # noqa: E501
        """
        pass

    def test_search_service_account_for_facet(self):
        """Test case for search_service_account_for_facet

        Lists the values of a specific facet over the customer's service accounts  # noqa: E501
        """
        pass

    def test_search_service_account_for_facets(self):
        """Test case for search_service_account_for_facets

        Lists the values of one or more facets over the customer's service accounts  # noqa: E501
        """
        pass

    def test_search_tagged_source_entities(self):
        """Test case for search_tagged_source_entities

        Search over a customer's sources  # noqa: E501
        """
        pass

    def test_search_tagged_source_for_facet(self):
        """Test case for search_tagged_source_for_facet

        Lists the values of a specific facet over the customer's sources  # noqa: E501
        """
        pass

    def test_search_tagged_source_for_facets(self):
        """Test case for search_tagged_source_for_facets

        Lists the values of one or more facets over the customer's sources  # noqa: E501
        """
        pass

    def test_search_user_entities(self):
        """Test case for search_user_entities

        Search over a customer's users  # noqa: E501
        """
        pass

    def test_search_user_for_facet(self):
        """Test case for search_user_for_facet

        Lists the values of a specific facet over the customer's users  # noqa: E501
        """
        pass

    def test_search_user_for_facets(self):
        """Test case for search_user_for_facets

        Lists the values of one or more facets over the customer's users  # noqa: E501
        """
        pass

    def test_search_user_group_entities(self):
        """Test case for search_user_group_entities

        Search over a customer's user groups  # noqa: E501
        """
        pass

    def test_search_user_group_for_facet(self):
        """Test case for search_user_group_for_facet

        Lists the values of a specific facet over the customer's user groups  # noqa: E501
        """
        pass

    def test_search_user_group_for_facets(self):
        """Test case for search_user_group_for_facets

        Lists the values of one or more facets over the customer's user groups  # noqa: E501
        """
        pass

    def test_search_web_hook_entities(self):
        """Test case for search_web_hook_entities

        Search over a customer's webhooks  # noqa: E501
        """
        pass

    def test_search_web_hook_for_facet(self):
        """Test case for search_web_hook_for_facet

        Lists the values of a specific facet over the customer's webhooks  # noqa: E501
        """
        pass

    def test_search_webhook_for_facets(self):
        """Test case for search_webhook_for_facets

        Lists the values of one or more facets over the customer's webhooks  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
