# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import wavefront_api_client
from wavefront_api_client.api.user_group_api import UserGroupApi  # noqa: E501
from wavefront_api_client.rest import ApiException


class TestUserGroupApi(unittest.TestCase):
    """UserGroupApi unit test stubs"""

    def setUp(self):
        self.api = wavefront_api_client.api.user_group_api.UserGroupApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_roles_to_user_group(self):
        """Test case for add_roles_to_user_group

        Add multiple roles to a specific user group  # noqa: E501
        """
        pass

    def test_add_users_to_user_group(self):
        """Test case for add_users_to_user_group

        Add multiple users to a specific user group  # noqa: E501
        """
        pass

    def test_create_user_group(self):
        """Test case for create_user_group

        Create a specific user group  # noqa: E501
        """
        pass

    def test_delete_user_group(self):
        """Test case for delete_user_group

        Delete a specific user group  # noqa: E501
        """
        pass

    def test_get_all_user_groups(self):
        """Test case for get_all_user_groups

        Get all user groups for a customer  # noqa: E501
        """
        pass

    def test_get_user_group(self):
        """Test case for get_user_group

        Get a specific user group  # noqa: E501
        """
        pass

    def test_remove_roles_from_user_group(self):
        """Test case for remove_roles_from_user_group

        Remove multiple roles from a specific user group  # noqa: E501
        """
        pass

    def test_remove_users_from_user_group(self):
        """Test case for remove_users_from_user_group

        Remove multiple users from a specific user group  # noqa: E501
        """
        pass

    def test_update_user_group(self):
        """Test case for update_user_group

        Update a specific user group  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
