# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import wavefront_api_client
from wavefront_api_client.api.maintenance_window_api import MaintenanceWindowApi  # noqa: E501
from wavefront_api_client.rest import ApiException


class TestMaintenanceWindowApi(unittest.TestCase):
    """MaintenanceWindowApi unit test stubs"""

    def setUp(self):
        self.api = wavefront_api_client.api.maintenance_window_api.MaintenanceWindowApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_maintenance_window(self):
        """Test case for create_maintenance_window

        Create a maintenance window  # noqa: E501
        """
        pass

    def test_delete_maintenance_window(self):
        """Test case for delete_maintenance_window

        Delete a specific maintenance window  # noqa: E501
        """
        pass

    def test_get_all_maintenance_window(self):
        """Test case for get_all_maintenance_window

        Get all maintenance windows for a customer  # noqa: E501
        """
        pass

    def test_get_maintenance_window(self):
        """Test case for get_maintenance_window

        Get a specific maintenance window  # noqa: E501
        """
        pass

    def test_update_maintenance_window(self):
        """Test case for update_maintenance_window

        Update a specific maintenance window  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
