# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import wavefront_api_client
from wavefront_api_client.api.monitored_service_api import MonitoredServiceApi  # noqa: E501
from wavefront_api_client.rest import ApiException


class TestMonitoredServiceApi(unittest.TestCase):
    """MonitoredServiceApi unit test stubs"""

    def setUp(self):
        self.api = wavefront_api_client.api.monitored_service_api.MonitoredServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_all_services(self):
        """Test case for get_all_services

        Get all monitored services  # noqa: E501
        """
        pass

    def test_get_service(self):
        """Test case for get_service

        Get a specific application  # noqa: E501
        """
        pass

    def test_get_services_of_application(self):
        """Test case for get_services_of_application

        Get a specific application  # noqa: E501
        """
        pass

    def test_update_service(self):
        """Test case for update_service

        Update a specific service  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
