# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import wavefront_api_client
from wavefront_api_client.api.message_api import MessageApi  # noqa: E501
from wavefront_api_client.rest import ApiException


class TestMessageApi(unittest.TestCase):
    """MessageApi unit test stubs"""

    def setUp(self):
        self.api = wavefront_api_client.api.message_api.MessageApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_user_get_messages(self):
        """Test case for user_get_messages

        Gets messages applicable to the current user, i.e. within time range and distribution scope  # noqa: E501
        """
        pass

    def test_user_read_message(self):
        """Test case for user_read_message

        Mark a specific message as read  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
