# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import wavefront_api_client
from wavefront_api_client.api.metrics_policy_api import MetricsPolicyApi  # noqa: E501
from wavefront_api_client.rest import ApiException


class TestMetricsPolicyApi(unittest.TestCase):
    """MetricsPolicyApi unit test stubs"""

    def setUp(self):
        self.api = wavefront_api_client.api.metrics_policy_api.MetricsPolicyApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_metrics_policy(self):
        """Test case for get_metrics_policy

        Get the metrics policy  # noqa: E501
        """
        pass

    def test_get_metrics_policy_by_version(self):
        """Test case for get_metrics_policy_by_version

        Get a specific historical version of a metrics policy  # noqa: E501
        """
        pass

    def test_get_metrics_policy_history(self):
        """Test case for get_metrics_policy_history

        Get the version history of metrics policy  # noqa: E501
        """
        pass

    def test_revert_metrics_policy_by_version(self):
        """Test case for revert_metrics_policy_by_version

        Revert to a specific historical version of a metrics policy  # noqa: E501
        """
        pass

    def test_update_metrics_policy(self):
        """Test case for update_metrics_policy

        Update the metrics policy  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
