# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import wavefront_api_client
from wavefront_api_client.api.api_token_api import ApiTokenApi  # noqa: E501
from wavefront_api_client.rest import ApiException


class TestApiTokenApi(unittest.TestCase):
    """ApiTokenApi unit test stubs"""

    def setUp(self):
        self.api = wavefront_api_client.api.api_token_api.ApiTokenApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_token(self):
        """Test case for create_token

        Create new api token  # noqa: E501
        """
        pass

    def test_delete_token(self):
        """Test case for delete_token

        Delete the specified api token  # noqa: E501
        """
        pass

    def test_delete_token_service_account(self):
        """Test case for delete_token_service_account

        Delete the specified api token of the given service account  # noqa: E501
        """
        pass

    def test_generate_token_service_account(self):
        """Test case for generate_token_service_account

        Create a new api token for the service account  # noqa: E501
        """
        pass

    def test_get_all_tokens(self):
        """Test case for get_all_tokens

        Get all api tokens for a user  # noqa: E501
        """
        pass

    def test_get_tokens_service_account(self):
        """Test case for get_tokens_service_account

        Get all api tokens for the given service account  # noqa: E501
        """
        pass

    def test_update_token_name(self):
        """Test case for update_token_name

        Update the name of the specified api token  # noqa: E501
        """
        pass

    def test_update_token_name_service_account(self):
        """Test case for update_token_name_service_account

        Update the name of the specified api token for the given service account  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
