# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class TupleResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'key': 'Tuple',
        'value_list': 'list[TupleValueResult]'
    }

    attribute_map = {
        'key': 'key',
        'value_list': 'valueList'
    }

    def __init__(self, key=None, value_list=None, _configuration=None):  # noqa: E501
        """TupleResult - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._key = None
        self._value_list = None
        self.discriminator = None

        if key is not None:
            self.key = key
        if value_list is not None:
            self.value_list = value_list

    @property
    def key(self):
        """Gets the key of this TupleResult.  # noqa: E501

        The keys used to surface the dimensions.  # noqa: E501

        :return: The key of this TupleResult.  # noqa: E501
        :rtype: Tuple
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this TupleResult.

        The keys used to surface the dimensions.  # noqa: E501

        :param key: The key of this TupleResult.  # noqa: E501
        :type: Tuple
        """

        self._key = key

    @property
    def value_list(self):
        """Gets the value_list of this TupleResult.  # noqa: E501

        All the possible value combination satisfying the provided keys and their respective counts from the query keys.  # noqa: E501

        :return: The value_list of this TupleResult.  # noqa: E501
        :rtype: list[TupleValueResult]
        """
        return self._value_list

    @value_list.setter
    def value_list(self, value_list):
        """Sets the value_list of this TupleResult.

        All the possible value combination satisfying the provided keys and their respective counts from the query keys.  # noqa: E501

        :param value_list: The value_list of this TupleResult.  # noqa: E501
        :type: list[TupleValueResult]
        """

        self._value_list = value_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TupleResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TupleResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TupleResult):
            return True

        return self.to_dict() != other.to_dict()
