# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import wavefront_api_client
from wavefront_api_client.api.source_api import SourceApi  # noqa: E501
from wavefront_api_client.rest import ApiException


class TestSourceApi(unittest.TestCase):
    """SourceApi unit test stubs"""

    def setUp(self):
        self.api = wavefront_api_client.api.source_api.SourceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_source_tag(self):
        """Test case for add_source_tag

        Add a tag to a specific source  # noqa: E501
        """
        pass

    def test_create_source(self):
        """Test case for create_source

        Create metadata (description or tags) for a specific source  # noqa: E501
        """
        pass

    def test_delete_source(self):
        """Test case for delete_source

        Delete metadata (description and tags) for a specific source  # noqa: E501
        """
        pass

    def test_get_all_source(self):
        """Test case for get_all_source

        Get all sources for a customer  # noqa: E501
        """
        pass

    def test_get_source(self):
        """Test case for get_source

        Get a specific source for a customer  # noqa: E501
        """
        pass

    def test_get_source_tags(self):
        """Test case for get_source_tags

        Get all tags associated with a specific source  # noqa: E501
        """
        pass

    def test_remove_description(self):
        """Test case for remove_description

        Remove description from a specific source  # noqa: E501
        """
        pass

    def test_remove_source_tag(self):
        """Test case for remove_source_tag

        Remove a tag from a specific source  # noqa: E501
        """
        pass

    def test_set_description(self):
        """Test case for set_description

        Set description associated with a specific source  # noqa: E501
        """
        pass

    def test_set_source_tags(self):
        """Test case for set_source_tags

        Set all tags associated with a specific source  # noqa: E501
        """
        pass

    def test_update_source(self):
        """Test case for update_source

        Update metadata (description or tags) for a specific source.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
