# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import wavefront_api_client
from wavefront_api_client.api.cloud_integration_api import CloudIntegrationApi  # noqa: E501
from wavefront_api_client.rest import ApiException


class TestCloudIntegrationApi(unittest.TestCase):
    """CloudIntegrationApi unit test stubs"""

    def setUp(self):
        self.api = wavefront_api_client.api.cloud_integration_api.CloudIntegrationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_aws_external_id(self):
        """Test case for create_aws_external_id

        Create an external id  # noqa: E501
        """
        pass

    def test_create_cloud_integration(self):
        """Test case for create_cloud_integration

        Create a cloud integration  # noqa: E501
        """
        pass

    def test_delete_aws_external_id(self):
        """Test case for delete_aws_external_id

        DELETEs an external id that was created by Wavefront  # noqa: E501
        """
        pass

    def test_delete_cloud_integration(self):
        """Test case for delete_cloud_integration

        Delete a specific cloud integration  # noqa: E501
        """
        pass

    def test_disable_cloud_integration(self):
        """Test case for disable_cloud_integration

        Disable a specific cloud integration  # noqa: E501
        """
        pass

    def test_enable_cloud_integration(self):
        """Test case for enable_cloud_integration

        Enable a specific cloud integration  # noqa: E501
        """
        pass

    def test_get_all_cloud_integration(self):
        """Test case for get_all_cloud_integration

        Get all cloud integrations for a customer  # noqa: E501
        """
        pass

    def test_get_aws_external_id(self):
        """Test case for get_aws_external_id

        GETs (confirms) a valid external id that was created by Wavefront  # noqa: E501
        """
        pass

    def test_get_cloud_integration(self):
        """Test case for get_cloud_integration

        Get a specific cloud integration  # noqa: E501
        """
        pass

    def test_undelete_cloud_integration(self):
        """Test case for undelete_cloud_integration

        Undelete a specific cloud integration  # noqa: E501
        """
        pass

    def test_update_cloud_integration(self):
        """Test case for update_cloud_integration

        Update a specific cloud integration  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
